==> google_cloud_talent-1.0.0-py2.py3-none-any.whl: google/cloud/talent_v4beta1/services/tenant_service/pagers.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from typing import Any, AsyncIterable, Awaitable, Callable, Iterable, Sequence, Tuple

from google.cloud.talent_v4beta1.types import tenant
from google.cloud.talent_v4beta1.types import tenant_service


class ListTenantsPager:
    """A pager for iterating through ``list_tenants`` requests.

    This class thinly wraps an initial
    :class:`~.tenant_service.ListTenantsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``tenants`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListTenants`` requests and continue to iterate
    through the ``tenants`` field on the
    corresponding responses.

    All the usual :class:`~.tenant_service.ListTenantsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., tenant_service.ListTenantsResponse],
        request: tenant_service.ListTenantsRequest,
        response: tenant_service.ListTenantsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (:class:`~.tenant_service.ListTenantsRequest`):
                The initial request object.
            response (:class:`~.tenant_service.ListTenantsResponse`):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = tenant_service.ListTenantsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterable[tenant_service.ListTenantsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterable[tenant.Tenant]:
        for page in self.pages:
            yield from page.tenants

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListTenantsAsyncPager:
    """A pager for iterating through ``list_tenants`` requests.

    This class thinly wraps an initial
    :class:`~.tenant_service.ListTenantsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``tenants`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListTenants`` requests and continue to iterate
    through the ``tenants`` field on the
    corresponding responses.

    All the usual :class:`~.tenant_service.ListTenantsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[tenant_service.ListTenantsResponse]],
        request: tenant_service.ListTenantsRequest,
        response: tenant_service.ListTenantsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (:class:`~.tenant_service.ListTenantsRequest`):
                The initial request object.
            response (:class:`~.tenant_service.ListTenantsResponse`):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = tenant_service.ListTenantsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterable[tenant_service.ListTenantsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterable[tenant.Tenant]:
        async def async_generator():
            async for page in self.pages:
                for response in page.tenants:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)

==> google_cloud_talent-2.5.2-py2.py3-none-any.whl: google/cloud/talent_v4beta1/services/tenant_service/pagers.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import (
    Any,
    AsyncIterator,
    Awaitable,
    Callable,
    Sequence,
    Tuple,
    Optional,
    Iterator,
)

from google.cloud.talent_v4beta1.types import tenant
from google.cloud.talent_v4beta1.types import tenant_service


class ListTenantsPager:
    """A pager for iterating through ``list_tenants`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.talent_v4beta1.types.ListTenantsResponse` object, and
    provides an ``__iter__`` method to iterate through its
    ``tenants`` field.

    If there are more pages, the ``__iter__`` method will make additional
    ``ListTenants`` requests and continue to iterate
    through the ``tenants`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.talent_v4beta1.types.ListTenantsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., tenant_service.ListTenantsResponse],
        request: tenant_service.ListTenantsRequest,
        response: tenant_service.ListTenantsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiate the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.talent_v4beta1.types.ListTenantsRequest):
                The initial request object.
            response (google.cloud.talent_v4beta1.types.ListTenantsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = tenant_service.ListTenantsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    def pages(self) -> Iterator[tenant_service.ListTenantsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = self._method(self._request, metadata=self._metadata)
            yield self._response

    def __iter__(self) -> Iterator[tenant.Tenant]:
        for page in self.pages:
            yield from page.tenants

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)


class ListTenantsAsyncPager:
    """A pager for iterating through ``list_tenants`` requests.

    This class thinly wraps an initial
    :class:`google.cloud.talent_v4beta1.types.ListTenantsResponse` object, and
    provides an ``__aiter__`` method to iterate through its
    ``tenants`` field.

    If there are more pages, the ``__aiter__`` method will make additional
    ``ListTenants`` requests and continue to iterate
    through the ``tenants`` field on the
    corresponding responses.

    All the usual :class:`google.cloud.talent_v4beta1.types.ListTenantsResponse`
    attributes are available on the pager. If multiple requests are made, only
    the most recent response is retained, and thus used for attribute lookup.
    """

    def __init__(
        self,
        method: Callable[..., Awaitable[tenant_service.ListTenantsResponse]],
        request: tenant_service.ListTenantsRequest,
        response: tenant_service.ListTenantsResponse,
        *,
        metadata: Sequence[Tuple[str, str]] = ()
    ):
        """Instantiates the pager.

        Args:
            method (Callable): The method that was originally called, and
                which instantiated this pager.
            request (google.cloud.talent_v4beta1.types.ListTenantsRequest):
                The initial request object.
            response (google.cloud.talent_v4beta1.types.ListTenantsResponse):
                The initial response object.
            metadata (Sequence[Tuple[str, str]]): Strings which should be
                sent along with the request as metadata.
        """
        self._method = method
        self._request = tenant_service.ListTenantsRequest(request)
        self._response = response
        self._metadata = metadata

    def __getattr__(self, name: str) -> Any:
        return getattr(self._response, name)

    @property
    async def pages(self) -> AsyncIterator[tenant_service.ListTenantsResponse]:
        yield self._response
        while self._response.next_page_token:
            self._request.page_token = self._response.next_page_token
            self._response = await self._method(self._request, metadata=self._metadata)
            yield self._response

    def __aiter__(self) -> AsyncIterator[tenant.Tenant]:
        async def async_generator():
            async for page in self.pages:
                for response in page.tenants:
                    yield response

        return async_generator()

    def __repr__(self) -> str:
        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
